
===============
OpenCMISS Utils
===============

OpenCMISS utilities for Python.  This software can be found on PyPi and installed with the following command::

  pip install opencmiss.utils

Distribution
============

This software uses regex to extract the version number information from the package. The version number for this package is stored in 'src/opencmiss/utils/__init__.py'

